@@ -805,6 +805,7 @@ class ImputationKernel(ImputedData):
         """
         Combine two imputation kernels together.
         For compatibility, the following attributes of each must be equal:
+
             - working_data
             - iteration_count
             - categorical_feature
@@ -874,22 +875,6 @@ class ImputationKernel(ImputedData):
         """
         Candidate predictions can be pre-generated before imputing new data.
         This can save a substantial amount of time, especially if save_models == 1.
-
-        Parameters
-        ----------
-        dtypes: dict(var, dtype) default = automatic
-            A dict of variable: datatype pairs, which specify the
-            datatypes to store the candidate predictions as.
-            In 99% of cases, using a smaller bit will drastically
-            decrease the calculation time and the size of the kernel.
-            By default, the following rules are used:
-                regression objective: float32
-                binary objective: float16
-                multiclass objective: float16
-
-            It is up to the user to determine if a certain column
-            with regression objective can be safely cast to float16.
-
         """
         compile_objectives = self.mean_match_scheme["candidate_preds_objectives"]
 
@@ -920,6 +905,18 @@ class ImputationKernel(ImputedData):
         """
         self.candidate_preds = {}
 
+    def fit(self, X, y, **fit_params):
+        """
+        Method for fitting a kernel when used in a sklearn pipeline.
+        Should not be called by the user directly.
+        """
+        assert self.dataset_count() == 1, (
+            "miceforest kernel should be initialized with datasets=1 if "
+            + "being used in a sklearn pipeline."
+        )
+        self.mice(**fit_params)
+        return self
+
     def get_model(self, dataset, variable, iteration=None):
         """
         Return the model for a specific dataset, variable, iteration.
@@ -1216,6 +1213,14 @@ class ImputationKernel(ImputedData):
         if self.save_loggers:
             self.loggers.append(logger)
 
+    def transform(self, X, y=None):
+        """
+        Method for calling a kernel when used in a sklearn pipeline.
+        Should not be called by the user directly.
+        """
+        new_dat = self.impute_new_data(X, datasets=[0])
+        return new_dat.complete_data(dataset=0, inplace=False)
+
     def tune_parameters(
         self,
         dataset,
@@ -1347,18 +1352,22 @@ class ImputationKernel(ImputedData):
 
         Returns
         -------
-
         2 dicts: optimal_parameters, optimal_parameter_losses
 
         - optimal_parameters: dict
             A dict of the optimal parameters found for each variable.
             This can be passed directly to the variable_parameters parameter in mice()
-            for future iterations for extremely accurate imputation.
+
+            .. code-block:: text
+
                 {variable: {parameter_name: parameter_value}}
 
         - optimal_parameter_losses: dict
             The average out of fold cv loss obtained directly from
             lightgbm.cv() associated with the optimal parameter set.
+
+            .. code-block:: text
+
                 {variable: loss}
 
         """
@@ -1526,9 +1535,7 @@ class ImputationKernel(ImputedData):
             ways in which the dataset can be altered:
 
             1) complete_data() will fill in missing values
-            2) To save space, mice() references and manipulates self.working_data directly.
-                If self.working_data is a reference to the original dataset, the original
-                dataset will undergo these manipulations during the mice process.
+            2) mice() references and manipulates self.working_data directly.
 
         random_state: int or np.random.RandomState or None (default=None)
             The random state of the process. Ensures reproducibility. If None, the random state
@@ -1752,9 +1759,15 @@ class ImputationKernel(ImputedData):
         return imputed_data
 
     def start_logging(self):
+        """
+        Start saving loggers to self.loggers
+        """
         self.save_loggers = True
 
     def stop_logging(self):
+        """
+        Stop saving loggers to self.loggers
+        """
         self.save_loggers = False
 
     def save_kernel(
@@ -1820,12 +1833,13 @@ class ImputationKernel(ImputedData):
         Return a matrix of feature importance. The cells
         represent the normalized feature importance of the
         columns to impute the rows. This is calculated
-        internally by RandomForestRegressor/Classifier.
+        internally by lightgbm.Booster.feature_importance().
 
         Parameters
         ----------
         dataset: int
             The dataset to get the feature importance for.
+
         iteration: int
             The iteration to return the feature importance for.
             Right now, the model must be saved to return importance
@@ -1871,11 +1885,14 @@ class ImputationKernel(ImputedData):
         ----------
         dataset: int
             The dataset to plot the feature importance for.
+
         iteration: int
             The iteration to plot the feature importance of.
+
         normalize: book
             Should the values be normalize from 0-1?
             If False, values are raw from Booster.feature_importance()
+
         kw_plot
             Additional arguments sent to sns.heatmap()
 
